@@ -1,7 +1,7 @@
 # computerp.py - azurerm functions for the Microsoft.Compute resource provider
 
 from .restfns import do_delete, do_get, do_get_next, do_patch, do_post, do_put
-from .settings import azure_rm_endpoint, COMP_API, NETWORK_API
+from .settings import get_rm_endpoint, COMP_API, NETWORK_API
 import json
 
 
@@ -10,8 +10,7 @@ import json
 # create availability set
 def create_as(access_token, subscription_id, resource_group, as_name,
               update_domains, fault_domains, location):
-
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/availabilitySets/', as_name,
@@ -24,22 +23,26 @@ def create_as(access_token, subscription_id, resource_group, as_name,
     return do_put(endpoint, body, access_token)
 
 
-# create_vm(access_token, subscription_id, resource_group, vm_name, vm_size, publisher, offer, sku, version,
-#              nic_id, location, storage_type='standard_LRS', username='azure', password=None, public_key=None)
-# create a simple virtual machine - in most cases deploying an ARM template might be easier
-def create_vm(access_token, subscription_id, resource_group, vm_name, vm_size, publisher, offer, sku, version,
-              nic_id, location, storage_type='Standard_LRS', osdisk_name=None, username='azure', password=None, public_key=None):
-    endpoint = ''.join([azure_rm_endpoint,
-                '/subscriptions/', subscription_id,
-                '/resourceGroups/', resource_group,
-                '/providers/Microsoft.Compute/virtualMachines/', vm_name,
-                '?api-version=', COMP_API])
+# create_vm(access_token, subscription_id, resource_group, vm_name, vm_size, publisher, offer,
+#         sku, version, nic_id, location, storage_type='standard_LRS', username='azure',
+#         password=None, public_key=None)
+# create a simple virtual machine - in most cases deploying an ARM
+# template might be easier
+def create_vm(access_token, subscription_id, resource_group, vm_name, vm_size, publisher, offer,
+              sku, version, nic_id, location, storage_type='Standard_LRS', osdisk_name=None,
+              username='azure', password=None, public_key=None):
+    endpoint = ''.join([get_rm_endpoint(),
+                        '/subscriptions/', subscription_id,
+                        '/resourceGroups/', resource_group,
+                        '/providers/Microsoft.Compute/virtualMachines/', vm_name,
+                        '?api-version=', COMP_API])
     if osdisk_name is None:
         osdisk_name = vm_name + 'osdisk'
     vm_body = {'name': vm_name}
     vm_body['location'] = location
     properties = {'hardwareProfile': {'vmSize': vm_size}}
-    image_reference = {'publisher': publisher, 'offer': offer, 'sku': sku, 'version': version}
+    image_reference = {'publisher': publisher,
+                       'offer': offer, 'sku': sku, 'version': version}
     storage_profile = {'imageReference': image_reference}
     os_disk = {'name': osdisk_name}
     os_disk['managedDisk'] = {'storageAccountType': storage_type}
@@ -57,12 +60,13 @@ def create_vm(access_token, subscription_id, resource_group, vm_name, vm_size, p
         else:
             disable_pswd = False
         linux_config = {'disablePasswordAuthentication': disable_pswd}
-        pub_key = {'path': '/home/' + username +'/.ssh/authorized_keys'}
+        pub_key = {'path': '/home/' + username + '/.ssh/authorized_keys'}
         pub_key['keyData'] = public_key
         linux_config['ssh'] = {'publicKeys': [pub_key]}
         os_profile['linuxConfiguration'] = linux_config
     properties['osProfile'] = os_profile
-    network_profile = {'networkInterfaces': [{'id': nic_id, 'properties': {'primary': True}}]}
+    network_profile = {'networkInterfaces': [
+        {'id': nic_id, 'properties': {'primary': True}}]}
     properties['networkProfile'] = network_profile
     vm_body['properties'] = properties
     body = json.dumps(vm_body)
@@ -72,17 +76,17 @@ def create_vm(access_token, subscription_id, resource_group, vm_name, vm_size, p
 # create_vmss(access_token, subscription_id, resource_group, vmss_name, vm_size, capacity, \
 #   publisher, offer, sku, version, subnet_id, be_pool_id, lb_pool_id, \
 #   location, storage_type='Standard_LRS', username='azure', password=None, public_key=None, overprovision='true', \
-#   upgradePolicy='Manual')
+#   upgradePolicy='Manual', public_ip_per_vm=False)
 # create virtual machine scale set
-def create_vmss(access_token, subscription_id, resource_group, vmss_name, vm_size, capacity, \
-    publisher, offer, sku, version, subnet_id, be_pool_id, lb_pool_id, location, storage_type='Standard_LRS', \
-     username='azure', password=None, public_key=None, overprovision='true', \
-    upgradePolicy='Manual'):
-    endpoint = ''.join([azure_rm_endpoint,
-                '/subscriptions/', subscription_id,
-                '/resourceGroups/', resource_group,
-                '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
-                '?api-version=', COMP_API])
+def create_vmss(access_token, subscription_id, resource_group, vmss_name, vm_size, capacity,
+                publisher, offer, sku, version, subnet_id, be_pool_id, lb_pool_id, location, storage_type='Standard_LRS',
+                username='azure', password=None, public_key=None, overprovision='true',
+                upgradePolicy='Manual', public_ip_per_vm=False):
+    endpoint = ''.join([get_rm_endpoint(),
+                        '/subscriptions/', subscription_id,
+                        '/resourceGroups/', resource_group,
+                        '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
+                        '?api-version=', COMP_API])
 
     vmss_body = {'location': location}
     vmss_sku = {'name': vm_size, 'tier': 'Standard', 'capacity': capacity}
@@ -99,7 +103,7 @@ def create_vmss(access_token, subscription_id, resource_group, vmss_name, vm_siz
         else:
             disable_pswd = False
         linux_config = {'disablePasswordAuthentication': disable_pswd}
-        pub_key = {'path': '/home/' + username +'/.ssh/authorized_keys'}
+        pub_key = {'path': '/home/' + username + '/.ssh/authorized_keys'}
         pub_key['keyData'] = public_key
         linux_config['ssh'] = {'publicKeys': [pub_key]}
         os_profile['linuxConfiguration'] = linux_config
@@ -109,13 +113,16 @@ def create_vmss(access_token, subscription_id, resource_group, vmss_name, vm_siz
     os_disk['caching'] = 'ReadWrite'
     storage_profile = {'osDisk': os_disk}
     storage_profile['imageReference'] = \
-        {'publisher': publisher, 'offer': offer, 'sku': sku, 'version': version} 
+        {'publisher': publisher, 'offer': offer, 'sku': sku, 'version': version}
     vm_profile['storageProfile'] = storage_profile
     nic = {'name': vmss_name}
     ip_config = {'name': vmss_name}
-    ip_properties = {'subnet': { 'id': subnet_id}}
+    ip_properties = {'subnet': {'id': subnet_id}}
     ip_properties['loadBalancerBackendAddressPools'] = [{'id': be_pool_id}]
     ip_properties['loadBalancerInboundNatPools'] = [{'id': lb_pool_id}]
+    if public_ip_per_vm is True:
+        ip_properties['publicIpAddressConfiguration'] = {
+            'name': 'pubip', 'properties': {'idleTimeoutInMinutes': 15}}
     ip_config['properties'] = ip_properties
     nic['properties'] = {'primary': True, 'ipConfigurations': [ip_config]}
     network_profile = {'networkInterfaceConfigurations': [nic]}
@@ -130,7 +137,7 @@ def create_vmss(access_token, subscription_id, resource_group, vmss_name, vm_siz
 # deallocate_vm(access_token, subscription_id, resource_group, vm_name)
 # stop-deallocate a virtual machine
 def deallocate_vm(access_token, subscription_id, resource_group, vm_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachines/', vm_name,
@@ -142,7 +149,7 @@ def deallocate_vm(access_token, subscription_id, resource_group, vm_name):
 # delete_as(access_token, subscription_id, resource_group, as_name)
 # delete availability set
 def delete_as(access_token, subscription_id, resource_group, as_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/availabilitySets/', as_name,
@@ -153,7 +160,7 @@ def delete_as(access_token, subscription_id, resource_group, as_name):
 # delete_vm(access_token, subscription_id, resource_group, vm_name)
 # delete a virtual machine
 def delete_vm(access_token, subscription_id, resource_group, vm_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachines/', vm_name,
@@ -164,7 +171,7 @@ def delete_vm(access_token, subscription_id, resource_group, vm_name):
 # delete_vmss(access_token, subscription_id, resource_group, vmss_name)
 # delete a virtual machine scale set
 def delete_vmss(access_token, subscription_id, resource_group, vmss_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
@@ -175,7 +182,7 @@ def delete_vmss(access_token, subscription_id, resource_group, vmss_name):
 # delete_vmss_vm(access_token, subscription_id, resource_group, vmss_name, vm_ids)
 # delete a VM in a VM Scale Set
 def delete_vmss_vms(access_token, subscription_id, resource_group, vmss_name, vm_ids):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
@@ -187,7 +194,7 @@ def delete_vmss_vms(access_token, subscription_id, resource_group, vmss_name, vm
 # get_compute_usage(access_token, subscription_id, location)
 # list compute usage and limits for a location
 def get_compute_usage(access_token, subscription_id, location):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/providers/Microsoft.compute/locations/', location,
                         '/usages?api-version=', COMP_API])
@@ -197,7 +204,7 @@ def get_compute_usage(access_token, subscription_id, location):
 # get_vm(access_token, subscription_id, resource_group, vm_name)
 # get virtual machine details
 def get_vm(access_token, subscription_id, resource_group, vm_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachines/', vm_name,
@@ -208,7 +215,7 @@ def get_vm(access_token, subscription_id, resource_group, vm_name):
 # get_vm_extension(access_token, subscription_id, resource_group, vm_name, extension_name)
 # get details about a VM extension
 def get_vm_extension(access_token, subscription_id, resource_group, vm_name, extension_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachines/', vm_name,
@@ -220,7 +227,7 @@ def get_vm_extension(access_token, subscription_id, resource_group, vm_name, ext
 # get_vm_instance(access_token, subscription_id, resource_group, vm_name)
 # get operational details about the state of a VM
 def get_vm_instance_view(access_token, subscription_id, resource_group, vm_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachines/', vm_name,
@@ -231,7 +238,7 @@ def get_vm_instance_view(access_token, subscription_id, resource_group, vm_name)
 # get_vmss(access_token, subscription_id, resource_group, vmss_name)
 # get virtual machine scale set details
 def get_vmss(access_token, subscription_id, resource_group, vmss_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
@@ -242,7 +249,7 @@ def get_vmss(access_token, subscription_id, resource_group, vmss_name):
 # get_vmss_instance_view(access_token, subscription_id, resource_group, vmss_name)
 # get virtual machine scale set instance view
 def get_vmss_instance_view(access_token, subscription_id, resource_group, vmss_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
@@ -253,18 +260,40 @@ def get_vmss_instance_view(access_token, subscription_id, resource_group, vmss_n
 # get_vmss_nics(access_token, subscription_id, resource_group, vmss_name)
 # get NIC details for a VM Scale Set
 def get_vmss_nics(access_token, subscription_id, resource_group, vmss_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
-                        '/networkInterfaces?api-version=', NETWORK_API])
+                        '/networkInterfaces?api-version=', COMP_API])
+    return do_get(endpoint, access_token)
+
+
+# get_vmss_public_ips(access_token, subscription_id, resource_group, vmss_name)
+# get public IP address details for a VM scale set
+def get_vmss_public_ips(access_token, subscription_id, resource_group, vmss_name):
+    endpoint = ''.join([get_rm_endpoint(),
+                        '/subscriptions/', subscription_id,
+                        '/resourceGroups/', resource_group,
+                        '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
+                        '/publicipaddresses?api-version=', COMP_API])
+    return do_get(endpoint, access_token)
+
+
+# get_vmss_rolling_upgrades(access_token, subscription_id, resource_group, vmss_name)
+# get details of the latest VM scale set rolling upgrade
+def get_vmss_rolling_upgrades(access_token, subscription_id, resource_group, vmss_name):
+    endpoint = ''.join([get_rm_endpoint(),
+                        '/subscriptions/', subscription_id,
+                        '/resourceGroups/', resource_group,
+                        '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
+                        '/rollingUpgrades/latest?api-version=', COMP_API])
     return do_get(endpoint, access_token)
 
 
 # get_vmss_vm(access_token, subscription_id, resource_group, vmss_name, instance_id)
 # get individual VMSS VM details
 def get_vmss_vm(access_token, subscription_id, resource_group, vmss_name, instance_id):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
@@ -276,7 +305,7 @@ def get_vmss_vm(access_token, subscription_id, resource_group, vmss_name, instan
 # get_vmss_vm_instance_view(access_token, subscription_id, resource_group, vmss_name, instance_id)
 # get individual VMSS VM instance view
 def get_vmss_vm_instance_view(access_token, subscription_id, resource_group, vmss_name, instance_id):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
@@ -288,19 +317,19 @@ def get_vmss_vm_instance_view(access_token, subscription_id, resource_group, vms
 # get_vmss_vm_nics(access_token, subscription_id, resource_group, vmss_name, instance_id)
 # get NIC details for a VMSS VM
 def get_vmss_vm_nics(access_token, subscription_id, resource_group, vmss_name, instance_id):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
                         '/virtualMachines/', str(instance_id),
-                        '/networkInterfaces?api-version=', COMP_API])
+                        '/networkInterfaces?api-version=', NETWORK_API])
     return do_get(endpoint, access_token)
 
 
 # get_as(access_token, subscription_id, resource_group, as_name)
 # get availability set
 def get_as(access_token, subscription_id, resource_group, as_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/availabilitySets/', as_name,
@@ -311,7 +340,7 @@ def get_as(access_token, subscription_id, resource_group, as_name):
 # list_as_sub(access_token, subscription_id, resource_group)
 # list availability sets in a resource_group
 def list_as(access_token, subscription_id, resource_group):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/availabilitySets',
@@ -322,18 +351,17 @@ def list_as(access_token, subscription_id, resource_group):
 # list_as_sub(access_token, subscription_id)
 # list availability sets in a subscription
 def list_as_sub(access_token, subscription_id):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/providers/Microsoft.Compute/availabilitySets',
                         '?api-version=', COMP_API])
     return do_get_next(endpoint, access_token)
 
 
-
 # list_vm_images_sub(access_token, subscription_id)
 # list VM images in a subscription
 def list_vm_images_sub(access_token, subscription_id):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/providers/Microsoft.Compute/images',
                         '?api-version=', COMP_API])
@@ -343,7 +371,7 @@ def list_vm_images_sub(access_token, subscription_id):
 # list_vm_instance_view(access_token, subscription_id, resource_group)
 # list VM instances views in a resource group
 def list_vm_instance_view(access_token, subscription_id, resource_group):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachines',
@@ -354,7 +382,7 @@ def list_vm_instance_view(access_token, subscription_id, resource_group):
 # list_vms(access_token, subscription_id, resource_group)
 # list VMs in a resource group
 def list_vms(access_token, subscription_id, resource_group):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachines',
@@ -365,7 +393,7 @@ def list_vms(access_token, subscription_id, resource_group):
 # list_vms_sub(access_token, subscription_id)
 # list VMs in a subscription
 def list_vms_sub(access_token, subscription_id):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/providers/Microsoft.Compute/virtualMachines',
                         '?api-version=', COMP_API])
@@ -375,7 +403,7 @@ def list_vms_sub(access_token, subscription_id):
 # list_vmss(access_token, subscription_id, resource_group)
 # list VM Scale Sets in a resource group
 def list_vmss(access_token, subscription_id, resource_group):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachineScaleSets',
@@ -386,7 +414,7 @@ def list_vmss(access_token, subscription_id, resource_group):
 # list_vmss_skus(access_token, subscription_id, resource_group, vmss_name)
 # list the VM skus available for a VM Scale Set
 def list_vmss_skus(access_token, subscription_id, resource_group, vmss_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
@@ -398,7 +426,7 @@ def list_vmss_skus(access_token, subscription_id, resource_group, vmss_name):
 # list_vmss_sub(access_token, subscription_id)
 # list VM Scale Sets in a subscription
 def list_vmss_sub(access_token, subscription_id):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/providers/Microsoft.Compute/virtualMachineScaleSets',
                         '?api-version=', COMP_API])
@@ -406,9 +434,10 @@ def list_vmss_sub(access_token, subscription_id):
 
 
 # list_vmss_vm_instance_view(access_token, subscription_id, resource_group, vmss_name)
-# list the VMSS VM instance views in a scale set - uses do_get_next to get all of them in a loop
+# list the VMSS VM instance views in a scale set - uses do_get_next to get
+# all of them in a loop
 def list_vmss_vm_instance_view(access_token, subscription_id, resource_group, vmss_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
@@ -420,11 +449,11 @@ def list_vmss_vm_instance_view(access_token, subscription_id, resource_group, vm
 # gets one page of a paginated list of scale set VM instance views
 def list_vmss_vm_instance_view_pg(access_token, subscription_id, resource_group, vmss_name, link=None):
     if link is None:
-        endpoint = ''.join([azure_rm_endpoint,
-                        '/subscriptions/', subscription_id,
-                        '/resourceGroups/', resource_group,
-                        '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
-                        '/virtualMachines?$expand=instanceView&$select=instanceView&api-version=', COMP_API])
+        endpoint = ''.join([get_rm_endpoint(),
+                            '/subscriptions/', subscription_id,
+                            '/resourceGroups/', resource_group,
+                            '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
+                            '/virtualMachines?$expand=instanceView&$select=instanceView&api-version=', COMP_API])
     else:
         endpoint = link
     return do_get(endpoint, access_token)
@@ -433,7 +462,7 @@ def list_vmss_vm_instance_view_pg(access_token, subscription_id, resource_group,
 # list_vmss_vms(access_token, subscription_id, resource_group, vmss_name)
 # list the VMs in a VM Scale Set
 def list_vmss_vms(access_token, subscription_id, resource_group, vmss_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
@@ -445,7 +474,7 @@ def list_vmss_vms(access_token, subscription_id, resource_group, vmss_name):
 # poweroff_vmss(access_token, subscription_id, resource_group, vmss_name)
 # poweroff all the VMs in a virtual machine scale set
 def poweroff_vmss(access_token, subscription_id, resource_group, vmss_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
@@ -457,7 +486,7 @@ def poweroff_vmss(access_token, subscription_id, resource_group, vmss_name):
 # poweroff_vmss_vms(access_token, subscription_id, resource_group, vmss_name, instance_ids)
 # poweroff all the VMs in a virtual machine scale set
 def poweroff_vmss_vms(access_token, subscription_id, resource_group, vmss_name, instance_ids):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
@@ -467,9 +496,10 @@ def poweroff_vmss_vms(access_token, subscription_id, resource_group, vmss_name,
 
 
 # reimage_vmss_vms(access_token, subscription_id, resource_group, vmss_name, instance_ids)
-# reset specific VMs a virtual machine scale set to factory settings (OS drive is reset, temp drive is not)
+# reset specific VMs a virtual machine scale set to factory settings (OS
+# drive is reset, temp drive is not)
 def reimage_vmss_vms(access_token, subscription_id, resource_group, vmss_name, instance_ids):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
@@ -481,7 +511,7 @@ def reimage_vmss_vms(access_token, subscription_id, resource_group, vmss_name, i
 # restart_vm(access_token, subscription_id, resource_group, vm_name)
 # restart a virtual machine
 def restart_vm(access_token, subscription_id, resource_group, vm_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachines/',
@@ -494,7 +524,7 @@ def restart_vm(access_token, subscription_id, resource_group, vm_name):
 # restart_vmss(access_token, subscription_id, resource_group, vmss_name)
 # restart all the VMs in a virtual machine scale set
 def restart_vmss(access_token, subscription_id, resource_group, vmss_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
@@ -506,7 +536,7 @@ def restart_vmss(access_token, subscription_id, resource_group, vmss_name):
 # restart_vmss_vms(access_token, subscription_id, resource_group, vmss_name, instance_ids)
 # restart a specific VM in a virtual machine scale set
 def restart_vmss_vms(access_token, subscription_id, resource_group, vmss_name, instance_ids):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
@@ -518,19 +548,33 @@ def restart_vmss_vms(access_token, subscription_id, resource_group, vmss_name, i
 # scale_vmss(access_token, subscription_id, resource_group, vmss_name, size, tier, capacity)
 # change the instance count of an existing VM Scale Set
 def scale_vmss(access_token, subscription_id, resource_group, vmss_name, size, tier, capacity):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
                         '?api-version=', COMP_API])
-    body = '{"sku":{ "name":"' + size + '", "tier":"' + tier + '", "capacity":"' + str(capacity) + '"}}'
+    body = '{"sku":{ "name":"' + size + '", "tier":"' + \
+        tier + '", "capacity":"' + str(capacity) + '"}}'
+    return do_patch(endpoint, body, access_token)
+
+
+# scale_vmss_lite(access_token, subscription_id, resource_group, vmss_name, size, tier, capacity)
+# change the instance count of an existing VM Scale Set - testing patch
+# capacity only
+def scale_vmss_lite(access_token, subscription_id, resource_group, vmss_name, capacity):
+    endpoint = ''.join([get_rm_endpoint(),
+                        '/subscriptions/', subscription_id,
+                        '/resourceGroups/', resource_group,
+                        '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
+                        '?api-version=', COMP_API])
+    body = '{"sku":{"capacity":"' + str(capacity) + '"}}'
     return do_patch(endpoint, body, access_token)
 
 
 # start_vm(access_token, subscription_id, resource_group, vm_name)
 # start a virtual machine
 def start_vm(access_token, subscription_id, resource_group, vm_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachines/',
@@ -543,7 +587,7 @@ def start_vm(access_token, subscription_id, resource_group, vm_name):
 # start_vmss(access_token, subscription_id, resource_group, vmss_name)
 # start all the VMs in a virtual machine scale set
 def start_vmss(access_token, subscription_id, resource_group, vmss_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
@@ -555,7 +599,7 @@ def start_vmss(access_token, subscription_id, resource_group, vmss_name):
 # start_vmss_vms(access_token, subscription_id, resource_group, vmss_name, instance_ids)
 # start all the VMs in a virtual machine scale set
 def start_vmss_vms(access_token, subscription_id, resource_group, vmss_name, instance_ids):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
@@ -567,7 +611,7 @@ def start_vmss_vms(access_token, subscription_id, resource_group, vmss_name, ins
 # stopdalloc_vmss(access_token, subscription_id, resource_group, vmss_name)
 # stop all the VMs in a virtual machine scale set
 def stopdealloc_vmss(access_token, subscription_id, resource_group, vmss_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
@@ -579,7 +623,7 @@ def stopdealloc_vmss(access_token, subscription_id, resource_group, vmss_name):
 # stopdealloc_vmss_vms(access_token, subscription_id, resource_group, vmss_name, instance_ids)
 # stop all the VMs in a virtual machine scale set
 def stopdealloc_vmss_vms(access_token, subscription_id, resource_group, vmss_name, instance_ids):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
@@ -591,7 +635,7 @@ def stopdealloc_vmss_vms(access_token, subscription_id, resource_group, vmss_nam
 # stop_vm(access_token, subscription_id, resource_group, vm_name)
 # stop a virtual machine but don't deallocate resources (power off)
 def stop_vm(access_token, subscription_id, resource_group, vm_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachines/',
@@ -602,9 +646,10 @@ def stop_vm(access_token, subscription_id, resource_group, vm_name):
 
 
 # update_vm(access_token, subscription_id, resource_group, vm_name, body)
-# updates a VM model, that is put an updated virtual machine body, e.g. a sku version
+# updates a VM model, that is put an updated virtual machine body, e.g. a
+# sku version
 def update_vm(access_token, subscription_id, resource_group, vm_name, body):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachines/', vm_name,
@@ -613,9 +658,10 @@ def update_vm(access_token, subscription_id, resource_group, vm_name, body):
 
 
 # update_vmss(access_token, subscription_id, resource_group, vmss_name, body)
-# updates a VMSS model, that is put an updated virtual machine scale set body, e.g. a sku version
+# updates a VMSS model, that is put an updated virtual machine scale set
+# body, e.g. a sku version
 def update_vmss(access_token, subscription_id, resource_group, vmss_name, body):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
@@ -626,7 +672,7 @@ def update_vmss(access_token, subscription_id, resource_group, vmss_name, body):
 # upgrade_vmss_vms(access_token, subscription_id, resource_group, vmss_name, instance_ids)
 # upgrade specific VMs in a virtual machine scale set
 def upgrade_vmss_vms(access_token, subscription_id, resource_group, vmss_name, instance_ids):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
