@@ -1,7 +1,7 @@
 # networkrp.py - azurerm functions for the Microsoft.Network resource provider
 import json
 from .restfns import do_delete, do_get, do_put
-from .settings import azure_rm_endpoint, NETWORK_API
+from .settings import get_rm_endpoint, NETWORK_API
 
 
 # create_lb_with_nat_pool(access_token, subscription_id, resource_group, lb_name, public_ip_id, 
@@ -9,7 +9,7 @@ from .settings import azure_rm_endpoint, NETWORK_API
 # create a load balancer with inbound NAT pools
 def create_lb_with_nat_pool(access_token, subscription_id, resource_group, lb_name, public_ip_id, \
     fe_start_port, fe_end_port, backend_port, location):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                 '/subscriptions/', subscription_id,
                 '/resourceGroups/', resource_group,
                 '/providers/Microsoft.Network/loadBalancers/', lb_name,
@@ -39,7 +39,7 @@ def create_lb_with_nat_pool(access_token, subscription_id, resource_group, lb_na
 # create_nic(access_token, subscription_id, resource_group, nic_name, public_ip_id, subnet_id, location)
 # create a network interface with an associated public ip address
 def create_nic(access_token, subscription_id, resource_group, nic_name, public_ip_id, subnet_id, location, nsg_id=None):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                     '/subscriptions/', subscription_id,
                     '/resourceGroups/', resource_group,
                     '/providers/Microsoft.Network/networkInterfaces/', nic_name,
@@ -61,7 +61,7 @@ def create_nic(access_token, subscription_id, resource_group, nic_name, public_i
 # create_nsg(access_token, subscription_id, resource_group, nsg_name, location)
 # create network security group (use create_nsg_rule() to add rules to it)
 def create_nsg(access_token, subscription_id, resource_group, nsg_name, location):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Network/networkSecurityGroups/', nsg_name,
@@ -72,11 +72,11 @@ def create_nsg(access_token, subscription_id, resource_group, nsg_name, location
 
 
 # create_nsg_rule(access_token, subscription_id, resource_group, nsg_name, nsg_rule_name, 
-# description, protocol='Tcp', source_range='*', destination_range='*', source_prefix='Internet', 
+# description, protocol='Tcp', source_range='*', destination_range='*', source_prefix='*', 
 # destination_prefix='*', access = 'Allow', priority=100, direction='Inbound')
 # create network security group rule
-def create_nsg_rule(access_token, subscription_id, resource_group, nsg_name, nsg_rule_name, description, protocol='Tcp', source_range='*', destination_range='*', source_prefix='Internet', destination_prefix='*', access = 'Allow', priority=100, direction='Inbound'):
-    endpoint = ''.join([azure_rm_endpoint,
+def create_nsg_rule(access_token, subscription_id, resource_group, nsg_name, nsg_rule_name, description, protocol='Tcp', source_range='*', destination_range='*', source_prefix='*', destination_prefix='*', access = 'Allow', priority=100, direction='Inbound'):
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Network/networkSecurityGroups/', nsg_name,
@@ -88,8 +88,6 @@ def create_nsg_rule(access_token, subscription_id, resource_group, nsg_name, nsg
     properties['destinationPortRange'] = destination_range
     properties['sourceAddressPrefix'] = source_prefix
     properties['destinationAddressPrefix'] = destination_prefix
-    properties['sourceAddressPrefix'] = '*'
-    properties['destinationAddressPrefix'] = '*'
     properties['access'] = access
     properties['priority'] = priority
     properties['direction'] = direction
@@ -101,7 +99,7 @@ def create_nsg_rule(access_token, subscription_id, resource_group, nsg_name, nsg
 # create_public_ip(access_token, subscription_id, resource_group, public_ip_name, dns_label, location)
 # create a public ip address
 def create_public_ip(access_token, subscription_id, resource_group, public_ip_name, dns_label, location):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Network/publicIPAddresses/', public_ip_name,
@@ -114,10 +112,12 @@ def create_public_ip(access_token, subscription_id, resource_group, public_ip_na
     return do_put(endpoint, body, access_token)
 
 
-# create_vnet(access_token, subscription_id, resource_group, name, location, address_prefix='10.0.0.0/16', nsg_id=None))
+# create_vnet(access_token, subscription_id, resource_group, name, location, 
+#    address_prefix='10.0.0.0/16', subnet_prefix='10.0.0.0/16', nsg_id=None))
 # create a VNet with specified name and location. Optional subnet address prefix.
-def create_vnet(access_token, subscription_id, resource_group, name, location, address_prefix='10.0.0.0/16', nsg_id=None):
-    endpoint = ''.join([azure_rm_endpoint,
+def create_vnet(access_token, subscription_id, resource_group, name, location, \
+    address_prefix='10.0.0.0/16', subnet_prefix='10.0.0.0/16', nsg_id=None):
+    endpoint = ''.join([get_rm_endpoint(),
                     '/subscriptions/', subscription_id,
                     '/resourceGroups/', resource_group,
                     '/providers/Microsoft.Network/virtualNetworks/', name,
@@ -126,7 +126,7 @@ def create_vnet(access_token, subscription_id, resource_group, name, location, a
     vnet_body = {'location': location}
     properties = {'addressSpace': {'addressPrefixes': [address_prefix]}}
     subnet = {'name': 'subnet'}
-    subnet['properties'] = {'addressPrefix': address_prefix}
+    subnet['properties'] = {'addressPrefix': subnet_prefix}
     if nsg_id is not None:
         subnet['properties']['networkSecurityGroup'] = {'id': nsg_id}
     properties['subnets'] = [subnet]
@@ -138,7 +138,7 @@ def create_vnet(access_token, subscription_id, resource_group, name, location, a
 # delete_load_balancer(access_token, subscription_id, resource_group, nic_name)
 # delete a load balancer
 def delete_load_balancer(access_token, subscription_id, resource_group, lb_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                     '/subscriptions/', subscription_id,
                     '/resourceGroups/', resource_group,
                     '/providers/Microsoft.Network/loadBalancers/', lb_name,
@@ -149,7 +149,7 @@ def delete_load_balancer(access_token, subscription_id, resource_group, lb_name)
 # delete_nic(access_token, subscription_id, resource_group, nic_name)
 # delete a network interface
 def delete_nic(access_token, subscription_id, resource_group, nic_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                     '/subscriptions/', subscription_id,
                     '/resourceGroups/', resource_group,
                     '/providers/Microsoft.Network/networkInterfaces/', nic_name,
@@ -160,7 +160,7 @@ def delete_nic(access_token, subscription_id, resource_group, nic_name):
 # delete_nsg(access_token, subscription_id, resource_group, nsg_name)
 # delete network security group
 def delete_nsg(access_token, subscription_id, resource_group, nsg_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Network/networkSecurityGroups/', nsg_name,
@@ -171,7 +171,7 @@ def delete_nsg(access_token, subscription_id, resource_group, nsg_name):
 # delete_nsg_rule(access_token, subscription_id, resource_group, nsg_name, nsg_rule_name)
 # delete network security group rule
 def delete_nsg_rule(access_token, subscription_id, resource_group, nsg_name, nsg_rule_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Network/networkSecurityGroups/', nsg_name,
@@ -183,7 +183,7 @@ def delete_nsg_rule(access_token, subscription_id, resource_group, nsg_name, nsg
 # delete_public_ip(access_token, subscription_id, resource_group, public_ip_name)
 # delete a public ip addresses associated with a resource group
 def delete_public_ip(access_token, subscription_id, resource_group, public_ip_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Network/publicIPAddresses/', public_ip_name,
@@ -194,7 +194,7 @@ def delete_public_ip(access_token, subscription_id, resource_group, public_ip_na
 # delete_vnet(access_token, subscription_id, resource_group, name)
 # delete a virtual network
 def delete_vnet(access_token, subscription_id, resource_group, name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                     '/subscriptions/', subscription_id,
                     '/resourceGroups/', resource_group,
                     '/providers/Microsoft.Network/virtualNetworks/', name,
@@ -205,7 +205,7 @@ def delete_vnet(access_token, subscription_id, resource_group, name):
 # get_lb_nat_rule(access_token, subscription_id, resource_group, lb_name, rule_name)
 # get details about a load balancer inbound NAT rule
 def get_lb_nat_rule(access_token, subscription_id, resource_group, lb_name, rule_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Network/loadBalancers/', lb_name,
@@ -217,7 +217,7 @@ def get_lb_nat_rule(access_token, subscription_id, resource_group, lb_name, rule
 # get_load_balancer(access_token, subscription_id, resource_group, lb_name)
 # get details about a load balancer	
 def get_load_balancer(access_token, subscription_id, resource_group, lb_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Network/loadBalancers/', lb_name,
@@ -228,7 +228,7 @@ def get_load_balancer(access_token, subscription_id, resource_group, lb_name):
 # get_network_usage(access_token, subscription_id, location)
 # list network usage and limits for a location
 def get_network_usage(access_token, subscription_id, location):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/providers/Microsoft.Network/locations/', location,
                         '/usages?api-version=', NETWORK_API])
@@ -238,7 +238,7 @@ def get_network_usage(access_token, subscription_id, location):
 # get_nic(access_token, subscription_id, resource_group, nic_name)
 # get details about a network interface
 def get_nic(access_token, subscription_id, resource_group, nic_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Network/networkInterfaces/', nic_name,
@@ -249,7 +249,7 @@ def get_nic(access_token, subscription_id, resource_group, nic_name):
 # get_public_ip(access_token, subscription_id, resource_group)
 # get details about the named public ip address
 def get_public_ip(access_token, subscription_id, resource_group, ip_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Network/',
@@ -261,7 +261,7 @@ def get_public_ip(access_token, subscription_id, resource_group, ip_name):
 # get_vnet(access_token, subscription_id, resource_group, vnet_name)
 # get details about the named virtual network
 def get_vnet(access_token, subscription_id, resource_group, vnet_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Network/virtualNetworks/', vnet_name,
@@ -272,7 +272,7 @@ def get_vnet(access_token, subscription_id, resource_group, vnet_name):
 # list_lb_nat_rules(access_token, subscription_id, resource_group, lb_name)
 # list the inbound NAT rules for a load balancer
 def list_lb_nat_rules(access_token, subscription_id, resource_group, lb_name):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Network/loadBalancers/', lb_name,
@@ -283,7 +283,7 @@ def list_lb_nat_rules(access_token, subscription_id, resource_group, lb_name):
 # list_load_balancers(access_token, subscription_id)
 # list the load balancers in a subscription	
 def list_load_balancers(access_token, subscription_id):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/providers/Microsoft.Network/',
                         '/loadBalancers?api-version=', NETWORK_API])
@@ -293,7 +293,7 @@ def list_load_balancers(access_token, subscription_id):
 # list_load_balancers_rg(access_token, subscription_id, resource_group)
 # list the load balancers in a resource group	
 def list_load_balancers_rg(access_token, subscription_id, resource_group):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Network/',
@@ -304,7 +304,7 @@ def list_load_balancers_rg(access_token, subscription_id, resource_group):
 # list_nics(access_token, subscription_id)
 # list the network interfaces in a subscription
 def list_nics(access_token, subscription_id):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/providers/Microsoft.Network/',
                         '/networkInterfaces?api-version=', NETWORK_API])
@@ -314,7 +314,7 @@ def list_nics(access_token, subscription_id):
 # list_nics_rg(access_token, subscription_id, resource_group)
 # list network interface cards within a resource group	
 def list_nics_rg(access_token, subscription_id, resource_group):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Network/',
@@ -325,7 +325,7 @@ def list_nics_rg(access_token, subscription_id, resource_group):
 # list_public_ips(access_token, subscription_id, resource_group)
 # list the public ip addresses in a resource group	
 def list_public_ips(access_token, subscription_id, resource_group):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Network/',
@@ -336,7 +336,7 @@ def list_public_ips(access_token, subscription_id, resource_group):
 # list_vnets(access_token, subscription_id)
 # list the VNETs in a subscription	
 def list_vnets(access_token, subscription_id):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/providers/Microsoft.Network/',
                         '/virtualNetworks?api-version=', NETWORK_API])
@@ -346,7 +346,7 @@ def list_vnets(access_token, subscription_id):
 # list_vnets_rg(access_token, subscription_id)
 # list the VNETs in a resource group
 def list_vnets_rg(access_token, subscription_id, resource_group):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Network/',
@@ -357,9 +357,9 @@ def list_vnets_rg(access_token, subscription_id, resource_group):
 # update_load_balancer(access_token, subscription_id, resource_group, lb_name, body)
 # updates a load balancer model, i.e. PUT an updated LB body
 def update_load_balancer(access_token, subscription_id, resource_group, lb_name, body):
-    endpoint = ''.join([azure_rm_endpoint,
+    endpoint = ''.join([get_rm_endpoint(),
                         '/subscriptions/', subscription_id,
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Network/loadBalancers/', lb_name,
                         '?api-version=', NETWORK_API])
-    return do_put(endpoint, body, access_token)
\ No newline at end of file
+    return do_put(endpoint, body, access_token)
